@@ -16,6 +16,9 @@
 
 package com.google.gson.typeadapters;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
+
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
 import com.google.gson.JsonParseException;
@@ -24,13 +27,14 @@ import java.util.Calendar;
 import java.util.Date;
 import java.util.Locale;
 import java.util.TimeZone;
-import junit.framework.TestCase;
+import org.junit.Test;
 
-public final class UtcDateTypeAdapterTest extends TestCase {
+public final class UtcDateTypeAdapterTest {
   private final Gson gson = new GsonBuilder()
     .registerTypeAdapter(Date.class, new UtcDateTypeAdapter())
     .create();
 
+  @Test
   public void testLocalTimeZone() {
     Date expected = new Date();
     String json = gson.toJson(expected);
@@ -38,6 +42,7 @@ public final class UtcDateTypeAdapterTest extends TestCase {
     assertEquals(expected.getTime(), actual.getTime());
   }
 
+  @Test
   public void testDifferentTimeZones() {
     for (String timeZone : TimeZone.getAvailableIDs()) {
       Calendar cal = Calendar.getInstance(TimeZone.getTimeZone(timeZone));
@@ -53,6 +58,7 @@ public final class UtcDateTypeAdapterTest extends TestCase {
    * JDK 1.7 introduced support for XXX format to indicate UTC date. But Android is older JDK.
    * We want to make sure that this date is parseable in Android.
    */
+  @Test
   public void testUtcDatesOnJdkBefore1_7() {
     Gson gson = new GsonBuilder()
       .registerTypeAdapter(Date.class, new UtcDateTypeAdapter())
@@ -60,6 +66,7 @@ public final class UtcDateTypeAdapterTest extends TestCase {
     gson.fromJson("'2014-12-05T04:00:00.000Z'", Date.class);
   }
 
+  @Test
   public void testUtcWithJdk7Default() {
     Date expected = new Date();
     SimpleDateFormat iso8601Format = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSSXXX", Locale.US);
@@ -71,11 +78,13 @@ public final class UtcDateTypeAdapterTest extends TestCase {
     assertEquals(expected.getTime(), actual.getTime());
   }
 
+  @Test
   public void testNullDateSerialization() {
     String json = gson.toJson(null, Date.class);
     assertEquals("null", json);
   }
 
+  @Test
   public void testWellFormedParseException() {
     try {
       gson.fromJson("2017-06-20T14:32:30", Date.class);
