@@ -16,6 +16,11 @@
 
 package com.google.gson;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import com.google.gson.reflect.TypeToken;
 import com.google.gson.stream.JsonReader;
 import com.google.gson.stream.JsonWriter;
@@ -25,9 +30,9 @@ import java.io.StringWriter;
 import java.lang.reflect.Type;
 import java.util.Arrays;
 import java.util.List;
-import junit.framework.TestCase;
+import org.junit.Test;
 
-public final class MixedStreamTest extends TestCase {
+public final class MixedStreamTest {
 
   private static final Car BLUE_MUSTANG = new Car("mustang", 0x0000FF);
   private static final Car BLACK_BMW = new Car("bmw", 0x000000);
@@ -47,6 +52,7 @@ public final class MixedStreamTest extends TestCase {
       + "  }\n"
       + "]";
 
+  @Test
   public void testWriteMixedStreamed() throws IOException {
     Gson gson = new Gson();
     StringWriter stringWriter = new StringWriter();
@@ -62,6 +68,7 @@ public final class MixedStreamTest extends TestCase {
     assertEquals(CARS_JSON, stringWriter.toString());
   }
 
+  @Test
   public void testReadMixedStreamed() throws IOException {
     Gson gson = new Gson();
     StringReader stringReader = new StringReader(CARS_JSON);
@@ -74,6 +81,7 @@ public final class MixedStreamTest extends TestCase {
     jsonReader.endArray();
   }
 
+  @Test
   public void testReaderDoesNotMutateState() throws IOException {
     Gson gson = new Gson();
     JsonReader jsonReader = new JsonReader(new StringReader(CARS_JSON));
@@ -88,6 +96,7 @@ public final class MixedStreamTest extends TestCase {
     assertTrue(jsonReader.isLenient());
   }
 
+  @Test
   public void testWriteDoesNotMutateState() throws IOException {
     Gson gson = new Gson();
     JsonWriter jsonWriter = new JsonWriter(new StringWriter());
@@ -106,6 +115,7 @@ public final class MixedStreamTest extends TestCase {
     assertFalse(jsonWriter.isLenient());
   }
 
+  @Test
   public void testReadInvalidState() throws IOException {
     Gson gson = new Gson();
     JsonReader jsonReader = new JsonReader(new StringReader(CARS_JSON));
@@ -118,6 +128,7 @@ public final class MixedStreamTest extends TestCase {
     }
   }
 
+  @Test
   public void testReadClosed() throws IOException {
     Gson gson = new Gson();
     JsonReader jsonReader = new JsonReader(new StringReader(CARS_JSON));
@@ -129,6 +140,7 @@ public final class MixedStreamTest extends TestCase {
     }
   }
 
+  @Test
   public void testWriteInvalidState() throws IOException {
     Gson gson = new Gson();
     JsonWriter jsonWriter = new JsonWriter(new StringWriter());
@@ -140,6 +152,7 @@ public final class MixedStreamTest extends TestCase {
     }
   }
 
+  @Test
   public void testWriteClosed() throws IOException {
     Gson gson = new Gson();
     JsonWriter jsonWriter = new JsonWriter(new StringWriter());
@@ -153,6 +166,7 @@ public final class MixedStreamTest extends TestCase {
     }
   }
 
+  @Test
   public void testWriteNulls() {
     Gson gson = new Gson();
     try {
@@ -166,6 +180,7 @@ public final class MixedStreamTest extends TestCase {
     assertEquals("null", stringWriter.toString());
   }
 
+  @Test
   public void testReadNulls() {
     Gson gson = new Gson();
     try {
@@ -180,6 +195,7 @@ public final class MixedStreamTest extends TestCase {
     }
   }
 
+  @Test
   public void testWriteHtmlSafe() {
     List<String> contents = Arrays.asList("<", ">", "&", "=", "'");
     Type type = new TypeToken<List<String>>() {}.getType();
@@ -196,6 +212,7 @@ public final class MixedStreamTest extends TestCase {
         writer.toString());
   }
 
+  @Test
   public void testWriteLenient() {
     List<Double> doubles = Arrays.asList(Double.NaN, Double.NEGATIVE_INFINITY,
         Double.POSITIVE_INFINITY, -0.0d, 0.5d, 0.0d);
