@@ -15,27 +15,29 @@
  */
 package com.google.gson.functional;
 
+import static java.util.Collections.singletonList;
+import static org.junit.Assert.assertEquals;
+
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
 import com.google.gson.reflect.TypeToken;
 import java.util.List;
-import junit.framework.TestCase;
-
-import static java.util.Collections.singletonList;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Functional tests for leniency option.
  */
-public class LeniencyTest extends TestCase {
+public class LeniencyTest {
 
   private Gson gson;
 
-  @Override
-  protected void setUp() throws Exception {
-    super.setUp();
+  @Before
+  public void setUp() throws Exception {
     gson = new GsonBuilder().setLenient().create();
   }
 
+  @Test
   public void testLenientFromJson() {
     List<String> json = gson.fromJson(""
         + "[ # One!\n"
