@@ -15,6 +15,9 @@
  */
 package com.google.gson.protobuf.functional;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+
 import com.google.common.base.CaseFormat;
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
@@ -25,20 +28,20 @@ import com.google.gson.protobuf.generated.Bag.ProtoWithDifferentCaseFormat;
 import com.google.gson.protobuf.generated.Bag.ProtoWithRepeatedFields;
 import com.google.gson.protobuf.generated.Bag.SimpleProto;
 import com.google.protobuf.GeneratedMessageV3;
-import junit.framework.TestCase;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Functional tests for protocol buffers using complex and repeated fields
  *
  * @author Inderjeet Singh
  */
-public class ProtosWithComplexAndRepeatedFieldsTest extends TestCase {
+public class ProtosWithComplexAndRepeatedFieldsTest {
   private Gson gson;
   private Gson upperCamelGson;
 
-  @Override
-  protected void setUp() throws Exception {
-    super.setUp();
+  @Before
+  public void setUp() throws Exception {
     gson =
         new GsonBuilder()
             .registerTypeHierarchyAdapter(GeneratedMessageV3.class,
@@ -56,6 +59,7 @@ public class ProtosWithComplexAndRepeatedFieldsTest extends TestCase {
             .create();
   }
 
+  @Test
   public void testSerializeRepeatedFields() {
     ProtoWithRepeatedFields proto = ProtoWithRepeatedFields.newBuilder()
       .addNumbers(2)
@@ -69,6 +73,7 @@ public class ProtosWithComplexAndRepeatedFieldsTest extends TestCase {
     assertTrue(json.contains("count"));
   }
 
+  @Test
   public void testDeserializeRepeatedFieldsProto() {
     String json = "{numbers:[4,6],simples:[{msg:'bar'},{count:7}]}";
     ProtoWithRepeatedFields proto =
@@ -79,6 +84,7 @@ public class ProtosWithComplexAndRepeatedFieldsTest extends TestCase {
     assertEquals(7, proto.getSimples(1).getCount());
   }
 
+  @Test
   public void testSerializeDifferentCaseFormat() {
     final ProtoWithDifferentCaseFormat proto =
       ProtoWithDifferentCaseFormat.newBuilder()
@@ -90,6 +96,7 @@ public class ProtosWithComplexAndRepeatedFieldsTest extends TestCase {
     assertEquals("bar", json.get("NameThatTestsCaseFormat").getAsJsonArray().get(0).getAsString());
   }
 
+  @Test
   public void testDeserializeDifferentCaseFormat() {
     final String json = "{NameThatTestsCaseFormat:['bar'],AnotherField:'foo'}";
     ProtoWithDifferentCaseFormat proto =
